Configuring the import
======================

Setting preferences
-------------------

There are some preferences that should be set before starting
the first import to ensure that everything works correctly. Under
*Admin → Configuration → CSV import*, all import templates can
be configured.

* **Group type for department groups:** This group type will
  be set for department (i.e. subject) groups.
* **Prefix for long names of department groups:** This prefix
  will be added to the long name of all department group names.
* **Languages for date parsing:** Here you can set languages you
  want to use for parsing dates from the CSV file. Takes
  comma-separated data without spaces (e. g. `de,en_US`).

In addition, you should set the **country code for phone number parsing**
under the *Internationalisation* tab correctly.
